"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Dock = void 0;
const react_1 = __importDefault(require("react"));
const DockItemsContainer_1 = require("./DockItemsContainer");
const DockOffset_1 = require("./DockOffset");
function Dock(props) {
    const [magnifierX, setMagnifierX] = react_1.default.useState(null);
    const unmagnifiedItemWidth = props.itemWidth;
    const unmagnifiedDockWidth = unmagnifiedItemWidth * react_1.default.Children.count(props.children);
    const magnifierRadius = 
    // The magnifier's "area of effect" in a particular direction.
    unmagnifiedItemWidth * 3;
    const maxOffsetWidth = magnifierRadius * props.magnification;
    const maxDockWidth = unmagnifiedDockWidth + maxOffsetWidth;
    const itemWidths = react_1.default.Children.map(props.children, (child, index) => {
        if (magnifierX === null)
            return unmagnifiedItemWidth;
        const itemCenter = unmagnifiedItemWidth * index + unmagnifiedItemWidth / 2;
        const distanceFromItemCenter = Math.abs(magnifierX - itemCenter);
        const magnifierStrength = 
        // An item is most magnified when the magnifier is positioned over its center.
        Math.max(1 - distanceFromItemCenter / magnifierRadius, 0);
        return unmagnifiedItemWidth * (1 + magnifierStrength * props.magnification);
    });
    const dockWidth = itemWidths.reduce((sum, itemWidth) => sum + itemWidth, 0);
    const offsetWidth = Math.abs(maxDockWidth - dockWidth);
    // FIXME: This approach of applying the offset to only one side of the dock and
    // forcing the other side's offset to be zero is... bad. When the dock has less
    // than 5 items it simply won't work properly. Instead we should calculate an
    // independent offset for each side based on dock width and mouse position.
    const leftOffsetWidth = magnifierX === null
        ? maxOffsetWidth / 2
        : magnifierX < unmagnifiedDockWidth / 2
            ? offsetWidth
            : 0;
    const rightOffsetWidth = magnifierX === null
        ? maxOffsetWidth / 2
        : magnifierX >= unmagnifiedDockWidth / 2
            ? offsetWidth
            : 0;
    const onMagnify = (event) => {
        const boundingBox = event.currentTarget.getBoundingClientRect();
        const x = event.clientX - boundingBox.left - maxOffsetWidth / 2;
        if (x >= 0 && x < unmagnifiedDockWidth) {
            setMagnifierX(x);
        }
        else {
            onUnmagnify(); // The mouse isn't over any dock items.
        }
    };
    const onUnmagnify = () => {
        setMagnifierX(null);
    };
    return (react_1.default.createElement("div", { className: props.className, onMouseMove: onMagnify, onMouseLeave: onUnmagnify, style: {
            display: 'grid',
            gridTemplateColumns: 'auto auto auto',
        } },
        react_1.default.createElement(DockOffset_1.DockOffset, { width: leftOffsetWidth, height: unmagnifiedItemWidth, magnifyDirection: props.magnifyDirection, debug: props.debug }),
        react_1.default.createElement(DockItemsContainer_1.DockItemsContainer, { backgroundClassName: props.backgroundClassName, itemWidths: itemWidths, height: unmagnifiedItemWidth, magnifyDirection: props.magnifyDirection, debug: props.debug }, props.children),
        react_1.default.createElement(DockOffset_1.DockOffset, { width: rightOffsetWidth, height: unmagnifiedItemWidth, magnifyDirection: props.magnifyDirection, debug: props.debug })));
}
exports.Dock = Dock;
